@@ -27,7 +27,7 @@ class TextFormatter(Formatter):
             "=================",
         ]
 
-        label_width = max([len(label[1]) for label in self.summary_labels])
+        label_width = max(len(label[1]) for label in self.summary_labels)
 
         for summary_label in self.summary_labels:
             key = summary_label[0]
@@ -47,14 +47,13 @@ class TextFormatter(Formatter):
 
         return "\n".join(output)
 
-    # pylint: disable=no-self-use
     def render_message(self, message):
         output = []
 
         if message.location.module:
-            output.append("%s (%s):" % (message.location.module, message.location.path))
+            output.append(f"{message.location.module} ({self._make_path(message.location.path)}):")
         else:
-            output.append("%s:" % message.location.path)
+            output.append("%s:" % self._make_path(message.location.path))
 
         output.append(
             "    L%s:%s %s: %s - %s"
