@@ -16,10 +16,9 @@ class VSCodeFormatter(Formatter):
         output = []
 
         for message in sorted(self.messages):
-
             if cur_loc != message.location.path:
                 cur_loc = message.location.path
-                module_name = message.location.path.replace(os.path.sep, ".")
+                module_name = self._make_path(message.location.path).replace(os.path.sep, ".")
                 module_name = re.sub(r"(\.__init__)?\.py$", "", module_name)
 
                 header = "************* Module %s" % module_name
