@@ -5,7 +5,6 @@ from prospector.formatters.base import Formatter
 __all__ = ("YamlFormatter",)
 
 
-# pylint: disable=too-few-public-methods
 class YamlFormatter(Formatter):
     def render(self, summary=True, messages=True, profile=False):
         output = {}
@@ -17,7 +16,7 @@ class YamlFormatter(Formatter):
             output["profile"] = self.profile.as_dict()
 
         if messages:
-            output["messages"] = [m.as_dict() for m in self.messages]
+            output["messages"] = [self._message_to_dict(m) for m in self.messages]
 
         return yaml.safe_dump(
             output,
