@@ -1,18 +1,17 @@
 import mimetypes
-import os
-import re
+from pathlib import Path
 
 from dodgy.checks import check_file_contents
 
 from prospector.encoding import CouldNotHandleEncoding, read_py_file
+from prospector.finder import FileFinder
 from prospector.message import Location, Message
 from prospector.tools.base import ToolBase
 
 
-def module_from_path(path):
-    # note : assumes a relative path
-    module = re.sub(r"\.py", "", path)
-    return ".".join(module.split(os.path.sep)[1:])
+def module_from_path(path: Path):
+    # TODO hacky...
+    return ".".join(path.parts[1:-1] + (path.stem,))
 
 
 class DodgyTool(ToolBase):
@@ -20,11 +19,10 @@ class DodgyTool(ToolBase):
         # empty: just implementing to satisfy the ABC contract
         pass
 
-    def run(self, found_files):
-
+    def run(self, found_files: FileFinder):
         warnings = []
-        for filepath in found_files.iter_file_paths():
-            mimetype = mimetypes.guess_type(filepath)
+        for filepath in found_files.files:
+            mimetype = mimetypes.guess_type(str(filepath.absolute()))
             if mimetype[0] is None or not mimetype[0].startswith("text/") or mimetype[1] is not None:
                 continue
             try:
@@ -37,15 +35,7 @@ class DodgyTool(ToolBase):
         messages = []
         for warning in warnings:
             path = warning["path"]
-            prefix = os.path.commonprefix([found_files.rootpath, path])
-            loc = Location(
-                path,
-                module_from_path(path[len(prefix) :]),
-                "",
-                warning["line"],
-                0,
-                absolute_path=True,
-            )
+            loc = Location(path, module_from_path(path), "", warning["line"], 0)
             msg = Message("dodgy", warning["code"], loc, warning["message"])
             messages.append(msg)
 
