@@ -88,7 +88,6 @@ class ProspectorReporter(Reporter):
 
     # pylint: disable=too-many-arguments
     def record_message(self, filename=None, line=None, character=None, code=None, message=None):
-
         code = code or "F999"
         if code in self.ignore:
             return
@@ -152,7 +151,7 @@ class PyFlakesTool(ToolBase):
 
     def run(self, found_files):
         reporter = ProspectorReporter(ignore=self.ignore_codes)
-        for filepath in found_files.iter_module_paths():
-            checkPath(filepath, reporter)
+        for filepath in found_files.python_modules:
+            checkPath(str(filepath.absolute()), reporter)
 
         return reporter.get_messages()
